@@ -11,17 +11,10 @@ from tacview_client import client, serve_file, db, config
 LOG = config.get_logger()
 app = typer.Typer()
 
-pg_option = typer.Option(
-    ...,
-    "--postges_dsn",
-    help="""DSN for connection to the postgres server. Format should be:\n
-    postgresql://{ip}:{port}/{dbname}?user={username}&password={password}""",
-)
-
 
 @app.command("run")
 def tacview(
-    postgres_dsn: str = pg_option,
+    # postgres_dsn: str = pg_option,
     host: str = typer.Option(
         ...,
         "--host",
@@ -32,14 +25,14 @@ def tacview(
         """,
     ),
     port: int = typer.Option(
-        ...,
+        42674,
         "--port",
         help="""Port where the existing tacview stream is available.
         Tacview sets this to 42674 by default.
         Unless the server to which you are connecting has manually edited the tacview port,
         you should not need to modify this parameter.""",
     ),
-    filename: str = typer.Option(
+    filename: Path = typer.Option(
         None,
         "--filename",
         help="""Path to valid tacview acmi file that should be read.
@@ -76,9 +69,17 @@ def tacview(
                 debug=debug,
                 max_iters=None,
                 batch_size=batch_size,
-                dsn=postgres_dsn,
             )
             server_proc.terminate()
+        else:
+            LOG.info("Connecting to tacview stream...")
+            client.main(
+                host=host,
+                port=port,
+                debug=debug,
+                max_iters=None,
+                batch_size=500,
+            )
     except KeyboardInterrupt:
         LOG.info("tacview-client shutting down...")
     except Exception as err:
@@ -91,13 +92,14 @@ def tacview(
 
 
 @app.command("dropdb")
-def dropdb(postgres_dsn: str = pg_option):
+def dropdb():
     """Drop database tables."""
     LOG.info("Dropping tables from specified database...")
     db.drop_tables()
 
 
 @app.command("createdb")
-def createdb(postgres_dsn: str = pg_option):
+def createdb():
+    """Create database tables."""
     LOG.info("Creating tables in specified database...")
     db.create_tables()
