@@ -4,7 +4,7 @@ import os
 from pathlib import Path
 
 DB_URL = os.getenv(
-    "DATABASE_URL", "postgresql://0.0.0.0:5432/dcs?user=prod&password=pwd"
+    "TACVIEW_DATABASE_URL", "postgresql://0.0.0.0:5432/dcs?user=prod&password=pwd"
 )
 
 
